==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Layer/ts/Layer_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+66"/>
        <source>Layer Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
Wars&amp;twa
Użyj bieżącej &amp;warstwy</translatorcomment>
        <translation type="unfinished">Wars&amp;twa</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Showing all layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Locking all layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+176"/>
        <source>Leading or trailing spaces.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Nazwa warstwy jest pusta.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Warstwa już istnieje.</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Danych warstwy</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Nazwa warstwy:</translatorcomment>
        <translation type="unfinished">Nazwa warstwy:</translation>
    </message>
    <message>
        <source>Pen</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Otwieranie ostatniego pliku...
Otwieranie ostatniego pliku
Otwieranie przerwane</translatorcomment>
        <translation type="obsolete">Pióro</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kolor &amp;siatki:
Kolor siatki:
Kolor &amp;meta-siatki:</translatorcomment>
        <translation type="unfinished">Kolor:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Szerokość linii:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Rodzaj linii:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Layer/ts/Layer_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+97"/>
        <source>Layer Tools</source>
        <translation>Narzędzia warstwy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Wyświetla narzędzia warstw</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
Wars&amp;twa
Użyj bieżącej &amp;warstwy</translatorcomment>
        <translation>W&amp;arstwa</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Showing all layers</source>
        <translation>Wyświetlanie wszystkich warstw</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation>Ukrywanie wszystkich warstw</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Thawing all layers</source>
        <translation>Odmrażanie wszystkich warstw</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Freezing all layers</source>
        <translation>Zamrażanie wszystkich warstw</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Locking all layers</source>
        <translation>Blokowanie wszystkich warstw</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation>Odblokowywanie wszystkich warstw</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+191"/>
        <source>Leading or trailing spaces.</source>
        <translation>Poprzedzające lub końcowe odstępy.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Layer name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nazwa warstwy jest pusta.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Layer already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Warstwa już istnieje.</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dane warstwy</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Nazwa warstwy:</translatorcomment>
        <translation>Nazwa warstwy:</translation>
    </message>
    <message>
        <source>Pen</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Otwieranie ostatniego pliku...
Otwieranie ostatniego pliku
Otwieranie przerwane</translatorcomment>
        <translation type="obsolete">Pióro</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Atrybuty</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kolor &amp;siatki:
Kolor siatki:
Kolor &amp;meta-siatki:</translatorcomment>
        <translation>Kolor:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Szerokość linii:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rodzaj linii:</translation>
    </message>
</context>
</TS>
